# Contributing to Unicorn

We love your input! We want to make contributing to this project as easy and transparent as possible.

## Contribution recogniton

We use [All Contributors](https://allcontributors.org/docs/en/specification) specification to handle recognitions. For more details read [this](https://github.com/asyncapi/community/blob/master/recognize-contributors.md) document.

## Summary of the contribution flow

The following is a summary of the ideal contribution flow. Please, note that Pull Requests can also be rejected by the maintainers when appropriate.

```
    ┌───────────────────────┐
    │                       │
    │    Open an issue      │
    │  (a bug report or a   │
    │   feature request)    │
    │                       │
    └───────────────────────┘
               ⇩
    ┌───────────────────────┐
    │                       │
    │  Open a Pull Request  │
    │   (only after issue   │
    │     is approved)      │
    │                       │
    └───────────────────────┘
               ⇩
    ┌───────────────────────┐
    │                       │
    │   Your changes will   │
    │     be merged and     │
    │ published on the next │
    │        release        │
    │                       │
    └───────────────────────┘
```

## Code of Conduct

Unicorn has adopted a Code of Conduct that we expect project participants to adhere to. Please [read the full text](./CODE_OF_CONDUCT.md) so that you can understand what sort of behavior is expected.

## Our Development Process

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

See more details about developing `django-unicorn` locally in [DEVELOPING.md](developing.md).

## Issues

[Open an issue](https://github.com/adamghill/django-unicorn/issues/new) **only** if you want to report a bug or a feature. Don't open issues for questions or support, instead create a [discussion](https://github.com/adamghill/django-unicorn/discussions/new) and ask there.

## Bug Reports and Feature Requests

Please use our issues templates that provide you with hints on what information we need from you to help you out.

## Pull Requests

Pull Requests are the best way to create a failing test case or sample code to replicate an issue.

## License

When you submit changes, your submissions are understood to be under the same [MIT License](https://github.com/adamghill/django-unicorn/blob/master/LICENSE) that covers the project.

## References

This document was adapted from the open-source contribution guidelines for [Async API](https://github.com/asyncapi/.github/blob/master/CONTRIBUTING.md).